.. distribution

.. _pip: https://pypi.org/project/sdss-mangadap/
.. _Anaconda: https://www.continuum.io/DOWNLOADS
.. _conda: https://docs.conda.io/projects/conda/en/latest/index.html
.. _virtualenv: https://virtualenv.pypa.io/en/latest/
.. _python.org: https://www.python.org/
.. _toml: https://toml.io/en/

.. core

.. _glob.glob: https://docs.python.org/3/library/glob.html
.. _isinstance: https://docs.python.org/3/library/functions.html#isinstance
.. _logging.Logger: https://docs.python.org/3/library/logging.html
.. _logging.level: https://docs.python.org/3/library/logging.html#logging-levels
.. _PEP 8: https://www.python.org/dev/peps/pep-0008
.. _PEP 257: https://www.python.org/dev/peps/pep-0257
.. _argparse.Namespace: https://docs.python.org/3/library/argparse.html#argparse.Namespace
.. _argparse.ArgumentParser: https://docs.python.org/3/library/argparse.html#argparse.ArgumentParser
.. _configparser.ConfigParser: https://docs.python.org/3/library/configparser.html
.. _eval: https://docs.python.org/3/library/functions.html#eval
.. _Path: https://docs.python.org/3/library/pathlib.html
.. _Path.glob: https://docs.python.org/3/library/pathlib.html#pathlib.Path.glob

.. numpy

.. _numpy.ndarray: https://numpy.org/doc/stable/reference/generated/numpy.ndarray.html
.. _numpy.ma.MaskedArray: http://numpy.org/doc/stable/reference/maskedarray.baseclass.html
.. _numpy.recarray: https://numpy.org/doc/stable/reference/generated/numpy.recarray.html
.. _numpy.meshgrid: http://numpy.org/doc/stable/reference/generated/numpy.meshgrid.html
.. _numpy.where: http://numpy.org/doc/stable/reference/generated/numpy.where.html
.. _numpy.cov: https://numpy.org/doc/stable/reference/generated/numpy.cov.html
.. _numpy.ravel_multi_index: https://numpy.org/doc/stable/reference/generated/numpy.ravel_multi_index.html
.. _numpy.unravel_index: https://numpy.org/doc/stable/reference/generated/numpy.unravel_index.html
.. _numpy.polynomial.legendre.legvander: https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.legvander.html
.. _numpy.dtype: https://numpy.org/doc/stable/reference/generated/numpy.dtype.html

.. scipy

.. _scipy.optimize.least_squares: http://docs.scipy.org/doc/scipy/reference/generated/scipy.optimize.least_squares.html
.. _scipy.optimize.OptimizeResult: http://docs.scipy.org/doc/scipy/reference/generated/scipy.optimize.OptimizeResult.html
.. _scipy.interpolate.interp1d: https://docs.scipy.org/doc/scipy/reference/generated/scipy.interpolate.interp1d.html
.. _scipy.sparse.spmatrix: http://docs.scipy.org/doc/scipy/reference/generated/scipy.sparse.spmatrix.html
.. _scipy.sparse.csr_matrix: http://docs.scipy.org/doc/scipy/reference/generated/scipy.sparse.csr_matrix.html
.. _scipy.sparse.coo_matrix: http://docs.scipy.org/doc/scipy/reference/generated/scipy.sparse.coo_matrix.html
.. _scipy.sparse.triu: http://docs.scipy.org/doc/scipy/reference/generated/scipy.sparse.triu.html
.. _scipy.sparse.find: https://docs.scipy.org/doc/scipy/reference/generated/scipy.sparse.find.html
.. _scipy.linalg.lu_factor: http://docs.scipy.org/doc/scipy/reference/generated/scipy.linalg.lu_factor.html
.. _scipy.linalg.lu_solve: https://docs.scipy.org/doc/scipy/reference/generated/scipy.linalg.lu_solve.html
.. _scipy.spatial.KDTree: https://docs.scipy.org/doc/scipy/reference/generated/scipy.spatial.KDTree.html

.. matplotlib

.. _pyplot.imshow: http://matplotlib.org/api/pyplot_api.html#matplotlib.pyplot.imshow

.. astropy

.. _astropy.io.fits: http://docs.astropy.org/en/stable/io/fits/index.html
.. _astropy.io.fits.open: http://docs.astropy.org/en/stable/io/fits/api/files.html#astropy.io.fits.open
.. _astropy.io.fits.HDUList: http://docs.astropy.org/en/stable/io/fits/api/hdulists.html
.. _astropy.io.fits.Header: http://docs.astropy.org/en/stable/io/fits/api/headers.html#header
.. _astropy.io.fits.BinTableHDU: http://docs.astropy.org/en/stable/io/fits/api/tables.html#astropy.io.fits.BinTableHDU
.. _astropy.io.fits.ImageHDU: https://docs.astropy.org/en/stable/io/fits/api/images.html#astropy.io.fits.ImageHDU
.. _astropy.io.fits.Column: http://docs.astropy.org/en/stable/io/fits/api/tables.html#astropy.io.fits.Column
.. _astropy.wcs.WCS: http://docs.astropy.org/en/stable/api/astropy.wcs.WCS.html
.. _astropy.modeling: http://docs.astropy.org/en/stable/modeling/index.html
.. _astropy.modeling.polynomial.Legendre1D: http://docs.astropy.org/en/stable/api/astropy.modeling.polynomial.Legendre1D.html
.. _astropy.modeling.models.CompoundModel: http://docs.astropy.org/en/stable/modeling/compound-models.html
.. _astropy.modeling.FittableModel: http://docs.astropy.org/en/stable/api/astropy.modeling.FittableModel.html
.. _astropy.cosmology.FlatLambdaCDM: http://docs.astropy.org/en/stable/api/astropy.cosmology.FlatLambdaCDM.html#flatlambdacdm
.. _astropy.constants: http://docs.astropy.org/en/stable/constants/index.html

.. pydl

.. _pydl.goddard.astro.airtovac: http://pydl.readthedocs.io/en/stable/api/pydl.goddard.astro.airtovac.html#pydl.goddard.astro.airtovac
.. _pydl.pydlutils.yanny: http://pydl.readthedocs.io/en/stable/api/pydl.pydlutils.yanny.yanny.html

.. misc packages

.. _requests: https://pypi.org/project/requests/
.. _IPython.embed: https://ipython.readthedocs.io/en/stable/interactive/reference.html#embedding
.. _configobj.ConfigObj: https://pypi.org/project/configobj/
.. _cvxopt: https://cvxopt.org/index.html
.. _ppxf: https://pypi.org/project/ppxf/
.. _shapely: https://pypi.python.org/pypi/Shapely
.. _vorbin: https://pypi.org/project/vorbin/
.. _tomli: https://pypi.org/project/tomli/
.. _spectres: https://pypi.org/project/spectres/

.. SDSS

.. _SDSS-style parameter file: http://www.sdss.org/dr16/software/par/
.. _SDSS Bitmasks: http://www.sdss.org/dr16/algorithms/bitmasks/
.. _Firefly VAC: https://www.sdss.org/dr16/manga/manga-data/manga-firefly-value-added-catalog/
.. _Pipe3D VAC: https://www.sdss.org/dr16/manga/manga-data/manga-pipe3d-value-added-catalog/
.. _MaNGA Bitmasks: https://www.sdss.org/dr16/manga/manga-data/metadata/#Bitmasks

.. citations

.. _Law et al. (2016, AJ, 152, 83): https://ui.adsabs.harvard.edu/abs/2016AJ....152...83L/abstract
.. _Westfall et al. (2019, AJ, 158, 231): https://ui.adsabs.harvard.edu/abs/2019AJ....158..231W/abstract
.. _Belfiore et al. (2019, AJ, 158, 160): https://ui.adsabs.harvard.edu/abs/2019AJ....158..160B/abstract
.. _Maraston et al. (2020, MNRAS, 496, 2962): https://ui.adsabs.harvard.edu/abs/2020MNRAS.496.2962M/abstract
.. _Law et al. (2021, AJ, 161, 52): https://ui.adsabs.harvard.edu/abs/2021AJ....161...52L/abstract
.. _Cappellari & Copin (2003, MNRAS, 342, 345): https://ui.adsabs.harvard.edu/abs/2003MNRAS.342..345C/abstract

.. mangadap github

.. _mangadap GitHub repo: https://github.com/sdss/mangadap
.. _Submit an issue: https://github.com/sdss/mangadap/issues

.. TRM

.. _DRPall: https://trac.sdss.org/wiki/MANGA/TRM/TRM_MPL-11/metadata#DRP:DRPall
.. _DRP datamodel: https://trac.sdss.org/wiki/MANGA/TRM/TRM_MPL-11/datamodel
.. _DRP HDUCLASS: https://trac.sdss.org/wiki/MANGA/TRM/TRM_MPL-11/datamodel#HDUCLASS
.. _DRP LOGCUBE: https://trac.sdss.org/wiki/MANGA/TRM/TRM_MPL-11/datamodel#manga-PLATE-IFUDESIGN-LOGCUBE.fits.gz

.. SAS

.. _DR15 SAS: https://dr15.sdss.org/sas/dr15/manga/spectro/analysis/v2_4_3/2.2.1/
.. _MPL-10 SAS: https://data.sdss.org/sas/mangawork/manga/spectro/analysis/v3_0_1/3.0.1
.. _MPL-11 SAS: https://data.sdss.org/sas/mangawork/manga/spectro/analysis/v3_1_1/3.1.0
.. _DR17 SAS: https://data.sdss.org/sas/dr17/manga/spectro/analysis/v3_1_1/3.1.0
.. _MANGA_SPECTRO_ANALYSIS: https://data.sdss.org/sas/mangawork/manga/spectro/analysis
.. _MANGA_SPECTRO_REDUX: https://data.sdss.org/sas/mangawork/manga/spectro/redux

.. _MPL-9 error report: https://data.sdss.org/sas/mangawork/manga/spectro/analysis/v2_7_1/2.4.1/log/error_report.txt
.. _MPL-10 error report: https://data.sdss.org/sas/mangawork/manga/spectro/analysis/v3_0_1/3.0.1/log/error_report.txt
.. _MPL-11 error report: https://data.sdss.org/sas/mangawork/manga/spectro/analysis/v3_1_1/3.1.0/log/error_report.txt

.. Example files

.. _manga-8138-12704-MAPS-HYB10-MILESHC-MASTARSSP.fits.gz: https://data.sdss.org/sas/mangawork/manga/spectro/analysis/MPL-11/HYB10-MILESHC-MASTARSSP/8138/12704/manga-8138-12704-MAPS-HYB10-MILESHC-MASTARSSP.fits.gz
.. _manga-8138-12704-LOGCUBE-HYB10-MILESHC-MASTARSSP.fits.gz: https://data.sdss.org/sas/mangawork/manga/spectro/analysis/MPL-11/HYB10-MILESHC-MASTARSSP/8138/12704/manga-8138-12704-LOGCUBE-HYB10-MILESHC-MASTARSSP.fits.gz

.. marvin

.. _Marvin: https://sdss-marvin.readthedocs.io
.. _install Marvin: https://sdss-marvin.readthedocs.io/en/latest/installation.html
.. _Marvin Maskbits utility: https://sdss-marvin.readthedocs.io/en/latest/reference/utils.html#module-marvin.utils.general.maskbit
.. _SDSS Collaboration Access: https://sdss-marvin.readthedocs.io/en/latest/installation.html#sdss-collaboration-access
